@@ -125,7 +125,7 @@ class MCPServer:
             },
             "execute_cypher_query": {
                 "name": "execute_cypher_query",
-                "description": "Fallback tool to run a direct, read-only Cypher query against the code graph.",
+                "description": "Fallback tool to run a direct, read-only Cypher query against the code graph. Use this for complex questions not covered by other tools. The graph contains nodes representing code structures and relationships between them. **Schema Overview:**\n- **Nodes:** `Repository`, `File`, `Module`, `Class`, `Function`.\n- **Properties:** Nodes have properties like `name`, `path`, `cyclomatic_complexity` (on Function nodes), and `code`.\n- **Relationships:** `CONTAINS` (e.g., File-[:CONTAINS]->Function), `CALLS` (Function-[:CALLS]->Function or File-[:CALLS]->Function), `IMPORTS` (File-[:IMPORTS]->Module), `INHERITS` (Class-[:INHERITS]->Class).",
                 "inputSchema": {
                     "type": "object",
                     "properties": { "cypher_query": {"type": "string", "description": "The read-only Cypher query to execute."} },
